using System.Collections;
using System.Collections.Generic;
using UnityEngine;

// https://youtu.be/mgmfZRllpzs
public class DrawLineWithMouse : MonoBehaviour
{
    public float timerDelay = 0.01f;
    float timer;

    List<Vector3> linePoints;
    GameObject lineObject;
    LineRenderer line;

    // Start is called before the first frame update
    void Start()
    {
        linePoints = new List<Vector3>();
    }

    Vector3 GetMousePosition()
    {
        Ray ray = Camera.main.ScreenPointToRay(Input.mousePosition);
        return ray.origin + ray.direction * 10f;
    }

    // Update is called once per frame
    void Update()
    {
        // If mouse button down, create a new line gameobject with line renderer component
        if (Input.GetMouseButtonDown(0))
        {
            // Create an empty game object
            lineObject = new GameObject();
            lineObject.transform.parent = this.gameObject.transform;
            // Create line renderer component and set its property
            line = lineObject.AddComponent<LineRenderer>();
            line.material = new Material(Shader.Find("Sprites/Default"));
            line.startWidth = 0.2f;
            line.endWidth = 0.2f;
            Color randomColor = Random.ColorHSV(0f, 1f, 1f, 1f, 0.5f, 1f);
            line.startColor = randomColor;
            line.endColor = randomColor;
        }

        // Drawing line when mouse is moving (add the current mouse position to linePoints & lineRenderer)
        if (Input.GetMouseButton(0)) {
            Debug.DrawRay(Camera.main.ScreenToWorldPoint(Input.mousePosition), GetMousePosition(), Color.red);

            timer -= Time.deltaTime;
            if (timer <= 0)
            {
                linePoints.Add(GetMousePosition()); // Add 3D mousepos into the list
                line.positionCount = linePoints.Count; // Update line renderer
                line.SetPositions(linePoints.ToArray());
                timer = timerDelay;
            }
        }

        // If mouse button up, clear the linePoints
        if (Input.GetMouseButtonUp(0))
        {
            //Debug.Log(linePoints.Count);
            linePoints.Clear(); // Clear the list
        }
    }
}
