using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class GLPrimitivesWithSpaceKey : MonoBehaviour
{
    int[] primitivemode = {GL.LINES, GL.LINE_STRIP, GL.TRIANGLES, GL.TRIANGLE_STRIP, GL.QUADS};
    int index = 0;
    Material mat = null;
    public float radius = 3.0f;
    public int segments = 16;

    void CreateMaterial()
	{
		if (!mat)
		{
			// Unity has a built-in shader that is useful for drawing
			// simple colored things.
			Shader shader = Shader.Find ("Hidden/Internal-Colored");
			mat = new Material (shader);
			mat.hideFlags = HideFlags.HideAndDontSave;
			// Turn on alpha blending
			mat.SetInt ("_SrcBlend", (int)UnityEngine.Rendering.BlendMode.SrcAlpha);
			mat.SetInt ("_DstBlend", (int)UnityEngine.Rendering.BlendMode.OneMinusSrcAlpha);
			// Turn backface culling off
			mat.SetInt ("_Cull", (int)UnityEngine.Rendering.CullMode.Off);
			// Turn off depth writes
			mat.SetInt ("_ZWrite", 0);
		}
	}

    void DrawCircle(int mode)
    {
        GL.PushMatrix();
        GL.MultMatrix(transform.localToWorldMatrix);
    
        GL.Begin(mode);
        GL.Color(Color.green);

        float deltaTheta = 2.0f * Mathf.PI / segments;
        for (int i = 0; i < segments; i++)
        {
            float theta = i * deltaTheta;
            float x = radius * Mathf.Cos(theta);
            float y = radius * Mathf.Sin(theta);
            GL.Vertex(new Vector3(x, y, 0));
        }

        GL.End();
        GL.PopMatrix();
    }

    // will be called after all regular rendering is done
    public void OnRenderObject()
    {
        CreateMaterial();
        mat.SetPass(0);

        DrawCircle(primitivemode[index]);
    }

    public void Update()
    {
        if (Input.GetKeyDown(KeyCode.Space))
        {
            index++;
            index = index % 5;
		    Debug.Log("primitivemode=" + primitivemode[index]);
        }
    }
}
